@@ -1,4 +1,4 @@
-/*  $Id: FrenchVerbDictionary.cpp,v 1.52 2012/11/18 19:56:05 sarrazip Exp $
+/*  $Id: FrenchVerbDictionary.cpp,v 1.55 2015/09/26 19:30:17 sarrazip Exp $
     FrenchVerbDictionary.cpp - Dictionary of verbs and conjugation templates
 
     verbiste - French conjugation system
@@ -153,8 +153,8 @@ FrenchVerbDictionary::parseLanguageCode(const std::string &twoLetterCode)
         return FRENCH;
     if (twoLetterCode == "it")
         return ITALIAN;
-    if (twoLetterCode == "el")
-        return GREEK;
+    //if (twoLetterCode == "el")
+    //    return GREEK;
     return NO_LANGUAGE;
 }
 
@@ -168,7 +168,7 @@ FrenchVerbDictionary::getLanguageCode(Language l)
     case NO_LANGUAGE: return "";
     case FRENCH: return "fr";
     case ITALIAN: return "it";
-    case GREEK: return "el";
+    case GREEK: return "";  // not supported
     }
     return "";
 }
